summaryrefslogtreecommitdiffstats
path: root/krita/ui/kis_dlg_adjustment_layer.h
diff options
context:
space:
mode:
Diffstat (limited to 'krita/ui/kis_dlg_adjustment_layer.h')
-rw-r--r--krita/ui/kis_dlg_adjustment_layer.h31
1 files changed, 16 insertions, 15 deletions
diff --git a/krita/ui/kis_dlg_adjustment_layer.h b/krita/ui/kis_dlg_adjustment_layer.h
index 93b32fda..4e20b8fd 100644
--- a/krita/ui/kis_dlg_adjustment_layer.h
+++ b/krita/ui/kis_dlg_adjustment_layer.h
@@ -22,14 +22,14 @@
#include <kdialogbase.h>
class KisFilter;
-class QIconViewItem;
-class QLabel;
-class QHBoxLayout;
+class TQIconViewItem;
+class TQLabel;
+class TQHBoxLayout;
class KisPreviewWidget;
class KisFiltersListView;
class KisFilterConfiguration;
class KisImage;
-class QGroupBox;
+class TQGroupBox;
/**
* Create a new adjustment layer.
@@ -38,6 +38,7 @@ class KisDlgAdjustmentLayer : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
@@ -49,35 +50,35 @@ public:
* @param caption the caption for the dialog -- create or properties
* @param create if true, set the dialog up for creating a new adj. layer, if false, edit the
* propeties of the current adj. layer
* @param parent the widget parent of this dialog
* @param name the QObject name, if any
*/
KisDlgAdjustmentLayer(KisImage * img,
- const QString & layerName,
- const QString & caption,
- QWidget *parent = 0,
+ const TQString & layerName,
+ const TQString & caption,
+ TQWidget *tqparent = 0,
const char *name = 0);
KisFilterConfiguration * filterConfiguration() const;
- QString layerName() const;
+ TQString layerName() const;
protected slots:
- void slotNameChanged( const QString & );
+ void slotNameChanged( const TQString & );
void slotConfigChanged();
void refreshPreview();
- void selectionHasChanged ( QIconViewItem * item );
+ void selectionHasChanged ( TQIconViewItem * item );
private:
KisImage * m_image;
KisPaintDeviceSP m_dev;
KisFiltersListView * m_filtersList;
KisPreviewWidget * m_preview;
- QGroupBox * m_configWidgetHolder;
- QWidget * m_currentConfigWidget;
+ TQGroupBox * m_configWidgetHolder;
+ TQWidget * m_currentConfigWidget;
KisFilter* m_currentFilter;
KLineEdit * m_layerName;
- QLabel* m_labelNoConfigWidget;
+ TQLabel* m_labelNoConfigWidget;
bool m_customName;
bool m_freezeName;
};
@@ -49,35 +50,35 @@ public:
* @param create if true, set the dialog up for creating a new adj. layer, if false, edit the
* propeties of the current adj. layer
- * @param parent the widget parent of this dialog
- * @param name the QObject name, if any
+ * @param tqparent the widget tqparent of this dialog
+ * @param name the TQObject name, if any
*/
KisDlgAdjustmentLayer(KisImage * img,